<?php 

namespace Teknisa\MAN\Controllers;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response;

class RetiradaConsumoPerdasController extends \Teknisa\MAN\Controllers\TeknisaCrud {
    
    protected $dataSourceName = 'retiradaConsumoPerdas';
    protected $parameterBagColumns = array("CDPRODUTOINI", "CDPRODUTOFIN", "DTINICIAL", "DTFINAL", "CDFILIAL");
    protected $environment;
    protected $ConsumoRealizadoService;
    
    public function __construct($crudService, EntityManager $entityManager, $environment, $ConsumoRealizadoService) {
        $this->crudService =$crudService;
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->ConsumoRealizadoService = $ConsumoRealizadoService;
    }
    
    public function findConsumoRealizado(DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $conditions = $request->getFilterCriteria()->getConditions();
            //$result = $this->ConsumoRealizadoService->findConsumoRealizado($conditions); Query na mao (não sei porque.......)
            
            parent::find($request, $response); //alterado para usar zeedhi
            
            //$dataSet = new DataSet($this->dataSourceName, $result);
            //$response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function saveConsumoRealizado (DTO\Request $request, DTO\Response $response) {
        try{
            $row = $request->getRow();

            if(isset($row["__is_new"]) && $row["__is_new"] ==  true){
                $result = $this->ConsumoRealizadoService->insertConsumoRealizado($row);
                $response->addDataSet(new DataSet('consumo_realizado_save', [$result]));
            } else {
                $result = $this->ConsumoRealizadoService->updateConsumoRealizado($row);
                $response->addDataSet(new DataSet('consumo_realizado_save', [$result]));
            }
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteConsumoRealizado (DTO\Request $request, DTO\Response $response) {
        try{
            $row = $request->getRow();
            $result = $this->ConsumoRealizadoService->deleteConsumoRealizado($row);
            $response->addDataSet(new DataSet('consumo_realizado_delete', [$result]));
        
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
  
    public function retiradaEstoqueConsumoRealizado (DTO\Request\DataSet $request, DTO\Response $response) {
        try{
            $rows = $request->getDataSet()->getRows();
            $consumos = $rows[0];
            $retirada = $rows[1];
   
            $result = $this->ConsumoRealizadoService->retiradaEstoqueConsumoRealizado($consumos, $retirada);
            if($result == true){
                if($result['IRREGULARES']?? 0 && count($result['IRREGULARES']) > 0){
                    $response->addDataSet(new DataSet('produtos_irregulares', $result['IRREGULARES']));
                }
                $response->addDataSet(new DataSet('consumo_realizado_retirada_estoque_rows', $result['LOG']));
            }
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    

}   