<?php

namespace Teknisa\MAN\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\MAN\Utilities;

class AssinaturaService {

	public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
		$this->connection = $entityManager->getConnection();
    }
    
    public function saveAssinatura($row) {
        $params = array(
            ':NRSERVASS'   => $row['NRSERVASS'],
            ':CDNCSERVASS' => $row['CDNCSERVASS'],
            ':NMSERVASS'   => $row['NMSERVASS'],
            ':DTVINGINI'   => $row['DTVINGINI'],
            ':DTVINGFIM'   => $row['DTVINGFIM'],
            ':URLARQTERMO' => $row['URLARQTERMO'],
            ':VRNCSERVASS' => $row['VRNCSERVASS'],
            ':NRFILASSOC'  => $row['NRFILASSOC']
        );
        
        $this->entityManager->getConnection()->executeQuery(self::INSERT_ASSINATURA, $params);
    }
    
    const INSERT_ASSINATURA = "
        INSERT INTO NCSERVASS(NRSERVASS, CDNCSERVASS, NMSERVASS, DTVINGINI, DTVINGFIM, URLARQTERMO, VRNCSERVASS, NRFILASSOC) 
            VALUES (:NRSERVASS, :CDNCSERVASS, :NMSERVASS, :DTVINGINI, :DTVINGFIM, :URLARQTERMO, :VRNCSERVASS, :NRFILASSOC)
    ";
    
    public function updateAssinatura($row) {
        $params = array(
            ':NRSERVASS'   => $row['NRSERVASS'],
            ':CDNCSERVASS' => $row['CDNCSERVASS'],
            ':NMSERVASS'   => $row['NMSERVASS'],
            ':DTVINGINI'   => $row['DTVINGINI'],
            ':DTVINGFIM'   => $row['DTVINGFIM'],
            ':URLARQTERMO' => $row['URLARQTERMO'],
            ':VRNCSERVASS' => $row['VRNCSERVASS'],
            ':NRORG'       => $row['NRORG']
        );
        
        $this->entityManager->getConnection()->executeQuery(self::UPDATE_ASSINATURA, $params);
    }
    
    const UPDATE_ASSINATURA = "
        UPDATE NCSERVASS
            SET NMSERVASS = :NMSERVASS,
                DTVINGINI = :DTVINGINI,
                DTVINGFIM = :DTVINGFIM,
                URLARQTERMO = :URLARQTERMO,
                VRNCSERVASS = :VRNCSERVASS
            WHERE NRSERVASS = :NRSERVASS
                AND CDNCSERVASS = :CDNCSERVASS
                AND NRORG = :NRORG
    ";
    
    public function deleteAssinaturaCascade($row) {
        $params = array(
            ':NRFILASSOC'  => $row['NRFILASSOC'],
            ':NRSERVASS'   => $row['NRSERVASS'],
            ':CDNCSERVASS' => $row['CDNCSERVASS'],
            ':NRORG'       => $row['NRORG']
        );
        
        $this->entityManager->getConnection()->executeQuery(self::DELETE_UNIDADE_ASSINATURA, $params);
 		return $this->entityManager->getConnection()->executeQuery(self::DELETE_ASSINATURA, $params);
    }
    
    const DELETE_UNIDADE_ASSINATURA = "
        DELETE FROM NCFILASSOC
            WHERE NRFILASSOC = :NRFILASSOC
                AND NRORG = :NRORG
    ";
    
    const DELETE_ASSINATURA = "
        DELETE FROM NCSERVASS
            WHERE NRSERVASS = :NRSERVASS
                AND CDNCSERVASS = :CDNCSERVASS
                AND NRORG = :NRORG
    ";
    
    public function saveFilial($row) {
        $params = array(
            ':NRFILASSOC' => $row['NRFILASSOC'],
            ':CDFILIAL'   => $row['CDFILIAL'],
            ':NRORG'      => $row['NRORG']
 		);
 		
 		$this->entityManager->getConnection()->executeQuery(self::INSERT_UNIDADE, $params);
    }
    
    const INSERT_UNIDADE = "
        INSERT INTO NCFILASSOC(NRFILASSOC, CDFILIAL, NRORG)
            VALUES(:NRFILASSOC, :CDFILIAL, :NRORG)
    ";
    
    public function deleteFilial($row) {
        $params = array(
            ':NRFILASSOC' => $row['NRFILASSOC'],
            ':CDFILIAL'   => $row['CDFILIAL'],
            ':NRORG'      => $row['NRORG']
 		);

 		$this->entityManager->getConnection()->executeQuery(self::DELETE_PARAM_FIN_UNIDADES, $params);
 		$this->entityManager->getConnection()->executeQuery(self::DELETE_UNIDADE, $params);
    }
    
    const DELETE_PARAM_FIN_UNIDADES = "
        DELETE FROM NCPARAMFIN
            WHERE CDFILIAL = :CDFILIAL
                AND NRORG = :NRORG
    ";
    
    const DELETE_UNIDADE = "
        DELETE FROM NCFILASSOC
            WHERE NRFILASSOC = :NRFILASSOC
                AND CDFILIAL = :CDFILIAL
                AND NRORG = :NRORG
    ";
    
    public function verificaUnidade($row) {
        $params = array(
            ':NRFILASSOC' => $row['NRFILASSOC'],
            ':CDFILIAL'   => $row['CDFILIAL'],
            ':NRORG'      => $row['NRORG']
 		);
 		
 		return $this->entityManager->getConnection()->fetchAll(self::GET_UNIDADE, $params);
    }
    
    const GET_UNIDADE = "
        SELECT 1
            FROM NCFILASSOC
            WHERE NRFILASSOC = :NRFILASSOC
                AND CDFILIAL = :CDFILIAL
                AND NRORG = :NRORG
    ";
    
    public function verificaCodigo($row) {
        $params = array(
            ':CDNCSERVASS' => $row['CDNCSERVASS'],
            ':NRORG'       => $row['NRORG']
 		);
 		
 		return $this->entityManager->getConnection()->fetchAll(self::GET_COD_SERVICO, $params);
    }
    
    const GET_COD_SERVICO = "
        SELECT 1
            FROM NCSERVASS
            WHERE CDNCSERVASS = :CDNCSERVASS
                AND NRORG = :NRORG
    ";
    
    public function deleteParametrizacaoFinanceira($row) {
        $params = array(
            ':NRPARAMFIN' => $row['NRPARAMFIN'],
            ':CDFILIAL'   => $row['LABELFILIAL'],
            ':NRORG'      => $row['NRORG']
 		);

 		$this->entityManager->getConnection()->executeQuery(self::DELETE_PARAM_FIN, $params);
    }
    
    const DELETE_PARAM_FIN = "
        DELETE FROM NCPARAMFIN
            WHERE NRPARAMFIN = :NRPARAMFIN
                AND CDFILIAL = :CDFILIAL
                AND NRORG = :NRORG
    ";
    
    public function saveParametrizacaoFinanceira($row) {
        $params = array(
            ':NRPARAMFIN' => $row['NRPARAMFIN'],
            ':CDFILIAL'   => $row['CDFILIAL'],
            ':DSFORMPG'   => $row['CDFORMPGTO'],
            ':CDCONTREC'  => $row['CDTPCTRECEB'],
            ':CDCONTCOR'  => $row['CDREDUCONT'],
            ':CDTPOPER'   => $row['CDTIPOOPER'],
            ':NRORG'      => $row['NRORG']
        );
        
        $this->entityManager->getConnection()->executeQuery(self::INSERT_PARAM_FIN, $params);
    }
    
    const INSERT_PARAM_FIN = "
        INSERT INTO NCPARAMFIN(NRPARAMFIN, CDFILIAL, DSFORMPG, CDCONTREC, CDCONTCOR, CDTPOPER, NRORG)
            VALUES(:NRPARAMFIN, :CDFILIAL, :DSFORMPG, :CDCONTREC, :CDCONTCOR, :CDTPOPER, :NRORG)
    ";
    
    public function updateParametrizacaoFinanceira($row) {
        if(!isset($row['CDFORMPGTO'])){
            $row['CDFORMPGTO'] = explode(" | ", $row['NMFORMPGTO'])[0];
        }
        
        if(!isset($row['CDTIPOOPER'])){
            $row['CDTIPOOPER']  = explode(" | ", $row['NMTIPOOPER'])[0];
        }
        
        if(!isset($row['CDREDUCONT'])){
            $row['CDREDUCONT']  = explode(" | ", $row['DSCONTCORR'])[0];
        }
        
        if(!isset($row['CDTPCTRECEB'])) {
            $row['CDTPCTRECEB'] = explode(" - ", $row['DSTPCTRECEB'])[0];
        }
        
        $params = array(
            ':NRPARAMFIN' => $row['NRPARAMFIN'],
            ':CDFILIAL'   => $row['LABELFILIAL'],
            ':DSFORMPG'   => $row['CDFORMPGTO'],
            ':CDCONTREC'  => $row['CDTPCTRECEB'],
            ':CDCONTCOR'  => $row['CDREDUCONT'],
            ':CDTPOPER'   => $row['CDTIPOOPER'],
            ':NRORG'      => $row['NRORG']
        );
        
        $this->entityManager->getConnection()->executeQuery(self::UPDATE_PARAM_FIN, $params);
    }
    
    const UPDATE_PARAM_FIN = "
        UPDATE NCPARAMFIN
            SET DSFORMPG = :DSFORMPG, 
                CDCONTREC = :CDCONTREC, 
                CDCONTCOR = :CDCONTCOR, 
                CDTPOPER = :CDTPOPER
            WHERE NRPARAMFIN = :NRPARAMFIN
                AND CDFILIAL = :CDFILIAL
                AND NRORG = :NRORG
    ";
}